(run source-directories test-directories test-fn)(run source-directories test-directories test-fn fn-name)(run source-directories test-directories test-fn fn-name ns-name)Run mutation testing on source and test directories. Directories may be a single path string or a collection of paths. Optional parameters: fn-name - filters mutations to a specific function ns-name - filters mutations to a specific namespace
Run mutation testing on source and test directories. Directories may be a single path string or a collection of paths. Optional parameters: fn-name - filters mutations to a specific function ns-name - filters mutations to a specific namespace
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |