mutant.internals


dependency-graphclj

(dependency-graph directory-names)
source

filter-forms-by-fn-nameclj

(filter-forms-by-fn-name forms fn-name)

Filter forms to only include defn/defn- with the given function name. If fn-name is nil, returns all forms unchanged.

Filter forms to only include defn/defn- with the given function name.
If fn-name is nil, returns all forms unchanged.
sourceraw docstring

formsclj

(forms file)

Return a collection of zippers for top-level sexprs found in a given file.

Return a collection of zippers for top-level sexprs found in a given file.
sourceraw docstring

namespacesclj

(namespaces directory-name)

Returns a map from files to namespaces in a given directory.

Returns a map from files to namespaces in a given directory.
sourceraw docstring

run-nsclj

(run-ns ns zippers dep-graph test-fn)
source

cljdoc builds & hosts documentation for Clojure/Script libraries