(filter-forms-by-fn-name forms fn-name)Filter forms to only include defn/defn- with the given function name. If fn-name is nil, returns all forms unchanged.
Filter forms to only include defn/defn- with the given function name. If fn-name is nil, returns all forms unchanged.
(forms file)Return a collection of zippers for top-level sexprs found in a given file.
Return a collection of zippers for top-level sexprs found in a given file.
(namespaces directory-name)Returns a map from files to namespaces in a given directory.
Returns a map from files to namespaces in a given directory.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |